# -*- coding: utf-8 -*-
import dash
from dash.dependencies import Input, Output
import dash_core_components as dcc
import dash_html_components as html

app = dash.Dash(__name__, url_base_pathname='/dash/')

all_options = {
    'America': ['New York City', 'San Francisco', 'Cincinnati'],
    'Canada': [u'Montréal', 'Toronto', 'Ottawa']
}
test_layout = html.Div([
    dcc.RadioItems(
        id='countries-dropdown',
        options=[{'label': k, 'value': k} for k in all_options.keys()],
        value='America'
    ),

    html.Hr(),

    dcc.RadioItems(id='cities-dropdown'),

    html.Hr(),

    html.Div(id='display-selected-values')
])


app.layout = html.Div([
    dcc.RadioItems(
        id='toc',
        value='initial',
        options=[{'label': i, 'value': i} for i in ['initial', 'test']]
    ),
    html.Div(id='output')
])

app.config.supress_callback_exceptions=True
app.scripts.config.serve_locally = True

@app.callback(
    dash.dependencies.Output('cities-dropdown', 'options'),
    [dash.dependencies.Input('countries-dropdown', 'value')])
def set_cities_options(selected_country):
    return [{'label': i, 'value': i} for i in all_options[selected_country]]

@app.callback(
    dash.dependencies.Output('cities-dropdown', 'value'),
    [dash.dependencies.Input('cities-dropdown', 'options')])
def set_cities_value(available_options):
    return available_options[0]['value']

@app.callback(
    dash.dependencies.Output('display-selected-values', 'children'),
    [dash.dependencies.Input('countries-dropdown', 'value'),
     dash.dependencies.Input('cities-dropdown', 'value')])
def set_display_children(selected_country, selected_city):
    return u'{} is a city in {}'.format(
        selected_city, selected_country,
    )

app.routes = [
    {
        'pathname': 'test',
        'state': {'toc.value': 'test'}
    }
]

@app.callback(
    dash.dependencies.Output('output', 'children'),
    [dash.dependencies.Input('toc', 'value')])
def display_output(value):
    if value == 'initial':
        return 'Initial value'
    else:
        return test_layout

if __name__ == '__main__':
    app.run_server(debug=True)
